package cn.sh.stc.sict.cloud.auth.handler;

import cn.sh.stc.sict.cloud.common.core.constant.SecurityConstants;
import cn.sh.stc.sict.cloud.common.security.handler.AuthenticationFailureHandler;
import cn.sh.stc.sict.cloud.common.security.util.SysLogUtils;
import cn.sh.stc.sict.cloud.upms.feign.RemoteLogService;
import cn.sh.stc.sict.cloud.upms.model.SysLog;
import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 *
 */
@Slf4j
@Component
@AllArgsConstructor
public class SictAuthenticationFailureLogEventHandler implements AuthenticationFailureHandler {

    private final RemoteLogService logService;

    /**
     * 异步处理，登录失败方法
     * <p>
     *
     * @param authenticationException 登录的authentication 对象
     * @param authentication          登录的authenticationException 对象
     * @param request                 请求
     * @param response                响应
     */
    @Async
    @Override
    @SneakyThrows
    public void handle(AuthenticationException authenticationException, Authentication authentication,
                       HttpServletRequest request, HttpServletResponse response) {
        String username = authentication.getName();
        SysLog sysLog = SysLogUtils.getSysLog(request, username);
        sysLog.setTitle(username + "用户登录");
        sysLog.setParams(username);
        sysLog.setException(authenticationException.getLocalizedMessage());

        logService.saveLog(sysLog, SecurityConstants.FROM_IN);

        log.info("用户：{} 登录失败，异常：{}", username, authenticationException.getLocalizedMessage());
    }

}
